% Script MSD_detect
%

% Copyright 2018, David W. Eaton, University of Calgary, all rights reserved
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

% This program accompanies the textbook "Passive Seismic Monitoring of
% Induced Seismicity: Fundamental Principles and Application to Energy
% Technologies", Cambridge University Press
%
% Please refer to the online manual for detailed usage instructions

% This script is part of the microseismic survey design (MSD) module
%
% It attempts to forecast the detectability of microseismic events based on
% user-supplied Q, noise level, microseismic efficiency, distance range,
% minimum and maximum magnitude values, and injected volume
%
% McGarr (1991) formula is used

close all;
clear;

prompt={'Q value','Background noise factor','Microseismic efficiency','b value','Minimum distance','Maximum distance','Minimum magnitude','Maximum magnitude','Injected volume (m^3)'};
name='MSD detect';
numlines=1;
defaultanswer={'200','1','0.001','2','100','1000','-3','0','4000'};
options.Resize='on';
options.WindowStyle='normal';
options.Interpreter='tex';
answer=inputdlg(prompt,name,numlines,defaultanswer,options);

Q = str2double(answer(1));
bgnf = str2double(answer(2));
xi = str2double(answer(3));
b = str2double(answer(4));
rmin = str2double(answer(5));
rmax = str2double(answer(6));
Mmin = str2double(answer(7));
Mmax = str2double(answer(8));
V = str2double(answer(9));

[hinoise,lonoise] = USGS_noise_model(10);
noise = bgnf*hinoise;

Mi = [Mmin:0.1:Mmax];
N = 10.^(-b*Mi);

dist = [rmin:50:rmax];

% Assume that the number of events increases with distance, proportional to
% volume of cylindrical shells

for i = 1:length(dist);
    Na(:,i) = N*dist(i);
end

% Computer seismic moment 

M0 = 10.^(1.5*(Mi+6));
M0 = M0';

for i = 1:length(dist);
    Ni = Na(:,i);
    M0bin(:,i) = Ni.*M0;
end

M0sum = sum(sum(M0bin));

mu = 1.5e10;

M0McGarr = mu*V;

% Computer number of events per bin after scaling

Na = Na*M0McGarr*xi/M0sum;

% Apply detection threshold

thresh = magthresh(Q,noise,Mi);

for i = 1:length(Mi);
    Ni = Na(i,:);
    Ni(dist>thresh(i)) = NaN;
    Na(i,:) = Ni;
end

Na(Na<1) = NaN;

nevents = nansum(nansum(Na))

pcolor(dist,Mi,Na);
shading flat;
colorbar vert;

text(dist(4),Mi(length(Mi)-3),['N_t = ',num2str(round((nevents)))]);

xlabel('Distance (m)');
ylabel('Moment magnitude');

title('Magnitude-Distance Graph Showing Forecast Detection Density');


    

